==> ci-hotel_V0.8.1_20100926.zip: ci-hotel_V0.8.1_20100926/system/application/views/admin/users/form.php <==
<?php echo validation_errors(); ?>

<table border="1px" width="100%">
<tr>
<td width="200px">氏名</td>
<td><input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>氏名カナ</td>
<td><input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>メールアドレス</td>
<td><input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>パスワード</td>
<td><input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>郵便番号</td>
<td><input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" /></td>
</tr>
<tr>
<td>都道府県</td>
<td><input type="text" name="prefecture" value="<?php echo set_value('prefecture', isset($prefecture) ? $prefecture : ''); ?>" size="10" /></td>
</tr>
<tr>
<td>市区町村</td>
<td><input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>番地</td>
<td><input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>電話番号</td>
<td><input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" /></td>
</tr>
</table>

<input type="submit" name="submit" />
</form>
>

==> ci-hotel_V0.9.2_20101011.zip: ci-hotel_V0.9.2_20101011/system/application/views/admin/users/form.php <==
<?php echo validation_errors(); ?>

<table border="1px" width="100%">
<tr>
<td width="200px">氏名</td>
<td><input type="text" name="name" value="<?php echo set_value('name', isset($name) ? $name : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>氏名カナ</td>
<td><input type="text" name="name_kana" value="<?php echo set_value('name_kana', isset($name_kana) ? $name_kana : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>メールアドレス</td>
<td><input type="text" name="email" value="<?php echo set_value('email', isset($email) ? $email : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>パスワード</td>
<td><input type="password" name="password" value="<?php echo set_value('password', isset($password) ? $password : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>ユーザタイプ</td><td>
<?php
$options = array(
                  'user'  => 'user',
                  'admin' => 'admin'
                );
echo form_dropdown('usertype', $options,  set_value('usertype', isset($usertype) ? $usertype : ''));
?>
</td></tr>
<tr>
<td>郵便番号</td>
<td><input type="text" name="postcode" value="<?php echo set_value('postcode', isset($postcode) ? $postcode : ''); ?>" size="10" /></td>
</tr>
<tr>
<td>都道府県</td>
<td><input type="text" name="prefecture" value="<?php echo set_value('prefecture', isset($prefecture) ? $prefecture : ''); ?>" size="10" /></td>
</tr>
<tr>
<td>市区町村</td>
<td><input type="text" name="city" value="<?php echo set_value('city', isset($city) ? $city : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>番地</td>
<td><input type="text" name="street" value="<?php echo set_value('street', isset($street) ? $street : ''); ?>" size="40" /></td>
</tr>
<tr>
<td>電話番号</td>
<td><input type="text" name="phone" value="<?php echo set_value('phone', isset($phone) ? $phone : ''); ?>" size="20" /></td>
</tr>
</table>

<input type="submit" name="submit" />
</form>
>
